@@ -1,8 +1,8 @@
 __author__ = """Romain Picard"""
 __email__ = 'romain.picard@oakbits.com'
-__version__ = '0.4.0'
+__version__ = '0.6.0'
 
-from .kafka import Sink, Source
+from .kafka import Sink, Source, DataFeedMode, DataSourceType
 from .kafka import Consumer, ConsumerTopic
 from .kafka import Producer, ProducerTopic
 from .kafka import make_driver
